@@ -531,3 +531,83 @@ def get_var(
 
     retrieved_vars = get_vars(namespace, key, envchain_cmd=envchain_cmd)
     return retrieved_vars.get(key)  # Returns None if key is not found
+
+
+def re_set_vars(
+    namespace: str,
+    require_passphrase: bool = False,
+    envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND,
+) -> None:
+    """
+    Re-sets all variables in the specified envchain namespace.
+    This involves getting all existing variables, unsetting them,
+    and then setting them again. This can be used, for example,
+    to change the --require-passphrase setting for existing entries.
+
+    Args:
+        namespace: The envchain namespace.
+        require_passphrase: If True, passes --require-passphrase to envchain
+                            when re-setting variables (macOS).
+        envchain_cmd: The envchain command to use.
+
+    Raises:
+        ValueError: If namespace is empty.
+        TypeError: If arguments have incorrect types.
+        EnvchainError: If any underlying envchain command fails.
+    """
+    if not isinstance(namespace, str) or not namespace.strip():
+        raise ValueError("Namespace must be a non-empty string.")
+    namespace = namespace.strip()
+
+    logger.info(f"Attempting to re-set variables for namespace '{namespace}'.")
+
+    # 1. Get existing variables
+    # get_vars will return an empty dict if namespace doesn't exist or is empty
+    existing_vars = get_vars(namespace, envchain_cmd=envchain_cmd)
+
+    if not existing_vars:
+        logger.info(
+            f"Namespace '{namespace}' is empty or does not exist. Nothing to re-set."
+        )
+        return
+
+    logger.debug(
+        f"Found {len(existing_vars)} variable(s) in namespace '{namespace}' to re-set."
+    )
+
+    # 2. Unset existing variables
+    # It's important to unset them before setting again to avoid potential
+    # issues if envchain --set behaves differently for existing vs. new keys
+    # or if the underlying storage has constraints.
+    try:
+        unset_vars(namespace, list(existing_vars.keys()), envchain_cmd=envchain_cmd)
+        logger.info(
+            f"Successfully unset {len(existing_vars)} variable(s) from '{namespace}' before re-setting."
+        )
+    except EnvchainError as e:
+        # If unsetting fails, it's a critical issue, so we re-raise.
+        logger.error(
+            f"Failed to unset variables in namespace '{namespace}' during re-set operation: {e}"
+        )
+        raise
+
+    # 3. Set them again with the (potentially new) require_passphrase setting
+    try:
+        set_vars(
+            namespace,
+            existing_vars,  # type: ignore
+            require_passphrase=require_passphrase,
+            envchain_cmd=envchain_cmd,
+        )
+        logger.info(
+            f"Successfully re-set {len(existing_vars)} variable(s) in namespace '{namespace}'."
+        )
+    except EnvchainError as e:
+        logger.error(
+            f"Failed to set variables in namespace '{namespace}' during re-set operation: {e}"
+        )
+        # Attempt to restore the original variables if re-setting fails?
+        # For now, let's just re-raise. The state might be partially modified.
+        # A more robust solution might involve transactions if envchain supported it,
+        # or a more complex rollback logic here.
+        raise
